@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,16 +23,17 @@
 #ifndef MAPNIK_GEOMETRY_INTERIOR_HPP
 #define MAPNIK_GEOMETRY_INTERIOR_HPP
 
-#include <mapnik/geometry.hpp>
 #include <mapnik/config.hpp> // for MAPNIK_DECL
+#include <mapnik/geometry/polygon.hpp>
+#include <mapnik/geometry/point.hpp>
 
-namespace mapnik { namespace geometry {
+namespace mapnik {
+namespace geometry {
 
-template <class T>
-MAPNIK_DECL bool interior(polygon<T> const& polygon,
-                          double scale_factor,
-                          point<T> & pt);
+template<class T>
+MAPNIK_DECL bool interior(polygon<T> const& polygon, double scale_factor, point<T>& pt);
 
-} }
+}
+} // namespace mapnik
 
 #endif // MAPNIK_GEOMETRY_INTERIOR_HPP
