@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,20 +24,21 @@
 #define MAPNIK_GEOMETRY_POLYGON_VERTEX_PROCESSOR_HPP
 
 // geometry
-#include <mapnik/geometry.hpp>
+#include <mapnik/geometry/point.hpp>
+#include <mapnik/geometry/polygon.hpp>
 
-namespace mapnik { namespace geometry {
+namespace mapnik {
+namespace geometry {
 
-template <typename T>
+template<typename T>
 struct polygon_vertex_processor
 {
-    template <typename Path>
-    void add_path(Path & path)
+    template<typename Path>
+    void add_path(Path& path)
     {
         point<T> p;
         unsigned cmd;
         linear_ring<T> ring;
-        bool exterior = true;
         while ((cmd = path.vertex(&p.x, &p.y)) != SEG_END)
         {
             switch (cmd)
@@ -51,15 +52,7 @@ struct polygon_vertex_processor
                     {
                         ring.emplace_back(ring.front());
                     }
-                    if (exterior)
-                    {
-                        polygon_.exterior_ring = std::move(ring);
-                        exterior = false;
-                    }
-                    else
-                    {
-                        polygon_.interior_rings.emplace_back(std::move(ring));
-                    }
+                    polygon_.emplace_back(std::move(ring));
                     ring = linear_ring<T>();
                     break;
             }
@@ -69,6 +62,7 @@ struct polygon_vertex_processor
     polygon<T> polygon_;
 };
 
-} }
+} // namespace geometry
+} // namespace mapnik
 
 #endif // MAPNIK_GEOMETRY_POLYGON_VERTEX_PROCESSOR_HPP
