@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,8 @@
 // mapnik
 #include <mapnik/feature.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore_agg.hpp>
 #include "agg_renderer_scanline.h"
 #include "agg_scanline_bin.h"
@@ -35,13 +36,13 @@
 #include "agg_span_allocator.h"
 #include "agg_image_accessors.h"
 #include "agg_span_image_filter_gray.h"
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 namespace mapnik {
 
-template <typename RendererType, typename RasterizerType>
+template<typename RendererType, typename RasterizerType>
 void render_raster_marker(RendererType ren,
-                          RasterizerType & ras,
+                          RasterizerType& ras,
                           image_rgba8 const& src,
                           mapnik::feature_impl const& feature,
                           agg::trans_affine const& marker_tr,
@@ -49,25 +50,29 @@ void render_raster_marker(RendererType ren,
 {
     using color_type = typename RendererType::color_type;
     agg::scanline_bin sl;
-    double width  = src.width();
+    double width = src.width();
     double height = src.height();
     double p[8];
-    p[0] = 0;     p[1] = 0;
-    p[2] = width; p[3] = 0;
-    p[4] = width; p[5] = height;
-    p[6] = 0;     p[7] = height;
+    p[0] = 0;
+    p[1] = 0;
+    p[2] = width;
+    p[3] = 0;
+    p[4] = width;
+    p[5] = height;
+    p[6] = 0;
+    p[7] = height;
     marker_tr.transform(&p[0], &p[1]);
     marker_tr.transform(&p[2], &p[3]);
     marker_tr.transform(&p[4], &p[5]);
     marker_tr.transform(&p[6], &p[7]);
-    ras.move_to_d(p[0],p[1]);
-    ras.line_to_d(p[2],p[3]);
-    ras.line_to_d(p[4],p[5]);
-    ras.line_to_d(p[6],p[7]);
+    ras.move_to_d(p[0], p[1]);
+    ras.line_to_d(p[2], p[3]);
+    ras.line_to_d(p[4], p[5]);
+    ras.line_to_d(p[6], p[7]);
     ren.color(color_type(feature.id()));
     agg::render_scanlines(ras, sl, ren);
 }
 
-}
+} // namespace mapnik
 
 #endif
