@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,14 +31,15 @@ namespace mapnik {
 
 struct webp_saver
 {
-    webp_saver(std::ostream &, std::string const&);
-    template <typename T>
-    void operator() (T const&) const;
+    webp_saver(std::ostream&, std::string const&);
+    template<typename T>
+    void operator()(T const&) const;
+
   private:
-    std::ostream & stream_;
+    std::ostream& stream_;
     std::string const& t_;
 };
 
-} // end ns
+} // namespace mapnik
 
 #endif // MAPNIK_IMAGE_UTIL_WEBP_HPP
