@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,12 +29,11 @@
 // stl
 #include <string>
 
-namespace mapnik
-{
+namespace mapnik {
 class Map;
 
 MAPNIK_DECL void save_map(Map const& map, std::string const& filename, bool explicit_defaults = false);
 MAPNIK_DECL std::string save_map_to_string(Map const& map, bool explicit_defaults = false);
-}
+} // namespace mapnik
 
 #endif // MAPNIK_SAVE_MAP_HPP
