@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2021 Artem Pavlenko
+ * Copyright (C) 2024 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,33 +30,34 @@
 #include <mapnik/svg/geometry_svg_generator.hpp>
 #include <mapnik/svg/output/svg_output_attributes.hpp>
 #include <mapnik/util/noncopyable.hpp>
-#include <mapnik/value_types.hpp>
+#include <mapnik/value/types.hpp>
 
+namespace mapnik {
+namespace svg {
 
-namespace mapnik { namespace svg {
+/*!
+ * @brief Performs the actual generation of output calling the underlying library.
+ * A method to generate each kind of SVG tag is provided. The information needed
+ * needed to generate the attributes of a tag is passed within a *_output_attributes
+ * structure.
+ */
+template<typename OutputIterator>
+class svg_generator : private util::noncopyable
+{
+  public:
+    explicit svg_generator(OutputIterator& output_iterator);
+    ~svg_generator();
 
-    /*!
-     * @brief Performs the actual generation of output calling the underlying library.
-     * A method to generate each kind of SVG tag is provided. The information needed
-     * needed to generate the attributes of a tag is passed within a *_output_attributes
-     * structure.
-     */
-    template <typename OutputIterator>
-    class svg_generator : private util::noncopyable
-    {
-    public:
-        explicit svg_generator(OutputIterator& output_iterator);
-        ~svg_generator();
-
-        void generate_header();
-        void generate_opening_root(root_output_attributes const& root_attributes);
-        void generate_closing_root();
-        void generate_rect(rect_output_attributes const& rect_attributes);
-        void generate_opening_group(mapnik::value_integer val);
-        void generate_opening_group(std::string const& val);
-        void generate_closing_group();
-        OutputIterator& output_iterator_;
-    };
-    }}
+    void generate_header();
+    void generate_opening_root(root_output_attributes const& root_attributes);
+    void generate_closing_root();
+    void generate_rect(rect_output_attributes const& rect_attributes);
+    void generate_opening_group(mapnik::value_integer val);
+    void generate_opening_group(std::string const& val);
+    void generate_closing_group();
+    OutputIterator& output_iterator_;
+};
+} // namespace svg
+} // namespace mapnik
 
 #endif // MAPNIK_SVG_GENERATOR_HPP
