@@ -561,7 +561,7 @@ featureset_ptr sqlite_datasource::features(query const& q) const
                                                    using_subquery_);
     }
 
-    return mapnik::make_invalid_featureset();
+    return mapnik::make_empty_featureset();
 }
 
 featureset_ptr sqlite_datasource::features_at_point(coord2d const& pt, double tol) const
@@ -640,5 +640,5 @@ featureset_ptr sqlite_datasource::features_at_point(coord2d const& pt, double to
                                                    using_subquery_);
     }
 
-    return mapnik::make_invalid_featureset();
+    return mapnik::make_empty_featureset();
 }
