@@ -125,7 +125,7 @@ featureset_ptr memory_datasource::features(const query& q) const
 {
     if (features_.empty())
     {
-        return mapnik::make_invalid_featureset();
+        return mapnik::make_empty_featureset();
     }
     return std::make_shared<memory_featureset>(q.get_bbox(), *this, bbox_check_);
 }
@@ -134,7 +134,7 @@ featureset_ptr memory_datasource::features_at_point(coord2d const& pt, double to
 {
     if (features_.empty())
     {
-        return mapnik::make_invalid_featureset();
+        return mapnik::make_empty_featureset();
     }
     box2d<double> box = box2d<double>(pt.x, pt.y, pt.x, pt.y);
     box.pad(tol);
