@@ -1,4 +1,3 @@
-
 #include "catch.hpp"
 #include "fake_path.hpp"
 
@@ -50,8 +49,10 @@ void test_simple_segment(double const& offset)
     fake_path path = {0, 0, 1, 0}, off_path = {0, offset, 1, offset};
     mapnik::offset_converter<fake_path> off_path_new(path);
     off_path_new.set_offset(offset);
-
-    double x0, y0, x1, y1;
+    double x0 = 0.0;
+    double y0 = 0.0;
+    double x1 = 0.0;
+    double y1 = 0.0;
     unsigned cmd0 = off_path_new.vertex(&x0, &y0);
     unsigned cmd1 = off_path.vertex(&x1, &y1);
     double d = dist(x0, y0, x1, y1);
@@ -94,10 +95,12 @@ void test_straight_line(double const& offset)
     fake_path path = {0, 0, 1, 0, 9, 0, 10, 0}, off_path = {0, offset, 1, offset, 9, offset, 10, offset};
     mapnik::offset_converter<fake_path> off_path_new(path);
     off_path_new.set_offset(offset);
-
-    double x0, y0, x1, y1;
+    double x0 = 0.0;
+    double y0 = 0.0;
+    double x1 = 0.0;
+    double y1 = 0.0;
     unsigned cmd0 = off_path_new.vertex(&x0, &y0);
-    unsigned cmd1 = off_path.vertex(&x1, &y1);
+    [[maybe_unused]] unsigned cmd1 = off_path.vertex(&x1, &y1);
     double d = dist(x0, y0, x1, y1);
     while (true)
     {
@@ -149,10 +152,12 @@ void test_offset_curve(double const& offset)
     fake_path path(pos), off_path(off_pos);
     mapnik::offset_converter<fake_path> off_path_new(path);
     off_path_new.set_offset(offset);
-
-    double x0, y0, x1, y1;
+    double x0 = 0.0;
+    double y0 = 0.0;
+    double x1 = 0.0;
+    double y1 = 0.0;
     unsigned cmd0 = off_path_new.vertex(&x0, &y0);
-    unsigned cmd1 = off_path.vertex(&x1, &y1);
+    [[maybe_unused]] unsigned cmd1 = off_path.vertex(&x1, &y1);
     double d = dist(x0, y0, x1, y1);
     while (true)
     {
@@ -213,10 +218,12 @@ void test_s_shaped_curve(double const& offset)
     fake_path path(pos), off_path(off_pos);
     mapnik::offset_converter<fake_path> off_path_new(path);
     off_path_new.set_offset(offset);
-
-    double x0, y0, x1, y1;
+    double x0 = 0.0;
+    double y0 = 0.0;
+    double x1 = 0.0;
+    double y1 = 0.0;
     unsigned cmd0 = off_path_new.vertex(&x0, &y0);
-    unsigned cmd1 = off_path.vertex(&x1, &y1);
+    [[maybe_unused]] unsigned cmd1 = off_path.vertex(&x1, &y1);
     double d = dist(x0, y0, x1, y1);
     while (true)
     {
